# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmAccessTokenEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'experiment': 'OrmExperiment',
        'model_service_revision': 'OrmModelServiceRevision',
        'pipeline_step_execution': 'OrmPipelineStepExecution',
        'run_execution': 'OrmRunExecution',
        'user': 'OrmUser',
        'workspace': 'OrmWorkspace'
    }

    attribute_map = {
        'experiment': 'experiment',
        'model_service_revision': 'model_service_revision',
        'pipeline_step_execution': 'pipeline_step_execution',
        'run_execution': 'run_execution',
        'user': 'user',
        'workspace': 'workspace'
    }

    def __init__(self, experiment=None, model_service_revision=None, pipeline_step_execution=None, run_execution=None, user=None, workspace=None, local_vars_configuration=None):  # noqa: E501
        """OrmAccessTokenEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._experiment = None
        self._model_service_revision = None
        self._pipeline_step_execution = None
        self._run_execution = None
        self._user = None
        self._workspace = None
        self.discriminator = None

        if experiment is not None:
            self.experiment = experiment
        if model_service_revision is not None:
            self.model_service_revision = model_service_revision
        if pipeline_step_execution is not None:
            self.pipeline_step_execution = pipeline_step_execution
        if run_execution is not None:
            self.run_execution = run_execution
        if user is not None:
            self.user = user
        if workspace is not None:
            self.workspace = workspace

    @property
    def experiment(self):
        """Gets the experiment of this OrmAccessTokenEdges.  # noqa: E501


        :return: The experiment of this OrmAccessTokenEdges.  # noqa: E501
        :rtype: OrmExperiment
        """
        return self._experiment

    @experiment.setter
    def experiment(self, experiment):
        """Sets the experiment of this OrmAccessTokenEdges.


        :param experiment: The experiment of this OrmAccessTokenEdges.  # noqa: E501
        :type experiment: OrmExperiment
        """

        self._experiment = experiment

    @property
    def model_service_revision(self):
        """Gets the model_service_revision of this OrmAccessTokenEdges.  # noqa: E501


        :return: The model_service_revision of this OrmAccessTokenEdges.  # noqa: E501
        :rtype: OrmModelServiceRevision
        """
        return self._model_service_revision

    @model_service_revision.setter
    def model_service_revision(self, model_service_revision):
        """Sets the model_service_revision of this OrmAccessTokenEdges.


        :param model_service_revision: The model_service_revision of this OrmAccessTokenEdges.  # noqa: E501
        :type model_service_revision: OrmModelServiceRevision
        """

        self._model_service_revision = model_service_revision

    @property
    def pipeline_step_execution(self):
        """Gets the pipeline_step_execution of this OrmAccessTokenEdges.  # noqa: E501


        :return: The pipeline_step_execution of this OrmAccessTokenEdges.  # noqa: E501
        :rtype: OrmPipelineStepExecution
        """
        return self._pipeline_step_execution

    @pipeline_step_execution.setter
    def pipeline_step_execution(self, pipeline_step_execution):
        """Sets the pipeline_step_execution of this OrmAccessTokenEdges.


        :param pipeline_step_execution: The pipeline_step_execution of this OrmAccessTokenEdges.  # noqa: E501
        :type pipeline_step_execution: OrmPipelineStepExecution
        """

        self._pipeline_step_execution = pipeline_step_execution

    @property
    def run_execution(self):
        """Gets the run_execution of this OrmAccessTokenEdges.  # noqa: E501


        :return: The run_execution of this OrmAccessTokenEdges.  # noqa: E501
        :rtype: OrmRunExecution
        """
        return self._run_execution

    @run_execution.setter
    def run_execution(self, run_execution):
        """Sets the run_execution of this OrmAccessTokenEdges.


        :param run_execution: The run_execution of this OrmAccessTokenEdges.  # noqa: E501
        :type run_execution: OrmRunExecution
        """

        self._run_execution = run_execution

    @property
    def user(self):
        """Gets the user of this OrmAccessTokenEdges.  # noqa: E501


        :return: The user of this OrmAccessTokenEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this OrmAccessTokenEdges.


        :param user: The user of this OrmAccessTokenEdges.  # noqa: E501
        :type user: OrmUser
        """

        self._user = user

    @property
    def workspace(self):
        """Gets the workspace of this OrmAccessTokenEdges.  # noqa: E501


        :return: The workspace of this OrmAccessTokenEdges.  # noqa: E501
        :rtype: OrmWorkspace
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this OrmAccessTokenEdges.


        :param workspace: The workspace of this OrmAccessTokenEdges.  # noqa: E501
        :type workspace: OrmWorkspace
        """

        self._workspace = workspace

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmAccessTokenEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmAccessTokenEdges):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponsePipelineStepRun(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'produced_output_volumes': 'list[str]',
        'run_spec': 'ResponseRunSpec',
        'variable_injects': 'dict[str, V1VariableReference]',
        'volume_injects': 'dict[str, V1VolumeInject]'
    }

    attribute_map = {
        'produced_output_volumes': 'produced_output_volumes',
        'run_spec': 'run_spec',
        'variable_injects': 'variable_injects',
        'volume_injects': 'volume_injects'
    }

    def __init__(self, produced_output_volumes=None, run_spec=None, variable_injects=None, volume_injects=None, local_vars_configuration=None):  # noqa: E501
        """ResponsePipelineStepRun - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._produced_output_volumes = None
        self._run_spec = None
        self._variable_injects = None
        self._volume_injects = None
        self.discriminator = None

        if produced_output_volumes is not None:
            self.produced_output_volumes = produced_output_volumes
        if run_spec is not None:
            self.run_spec = run_spec
        if variable_injects is not None:
            self.variable_injects = variable_injects
        if volume_injects is not None:
            self.volume_injects = volume_injects

    @property
    def produced_output_volumes(self):
        """Gets the produced_output_volumes of this ResponsePipelineStepRun.  # noqa: E501


        :return: The produced_output_volumes of this ResponsePipelineStepRun.  # noqa: E501
        :rtype: list[str]
        """
        return self._produced_output_volumes

    @produced_output_volumes.setter
    def produced_output_volumes(self, produced_output_volumes):
        """Sets the produced_output_volumes of this ResponsePipelineStepRun.


        :param produced_output_volumes: The produced_output_volumes of this ResponsePipelineStepRun.  # noqa: E501
        :type produced_output_volumes: list[str]
        """

        self._produced_output_volumes = produced_output_volumes

    @property
    def run_spec(self):
        """Gets the run_spec of this ResponsePipelineStepRun.  # noqa: E501


        :return: The run_spec of this ResponsePipelineStepRun.  # noqa: E501
        :rtype: ResponseRunSpec
        """
        return self._run_spec

    @run_spec.setter
    def run_spec(self, run_spec):
        """Sets the run_spec of this ResponsePipelineStepRun.


        :param run_spec: The run_spec of this ResponsePipelineStepRun.  # noqa: E501
        :type run_spec: ResponseRunSpec
        """

        self._run_spec = run_spec

    @property
    def variable_injects(self):
        """Gets the variable_injects of this ResponsePipelineStepRun.  # noqa: E501


        :return: The variable_injects of this ResponsePipelineStepRun.  # noqa: E501
        :rtype: dict[str, V1VariableReference]
        """
        return self._variable_injects

    @variable_injects.setter
    def variable_injects(self, variable_injects):
        """Sets the variable_injects of this ResponsePipelineStepRun.


        :param variable_injects: The variable_injects of this ResponsePipelineStepRun.  # noqa: E501
        :type variable_injects: dict[str, V1VariableReference]
        """

        self._variable_injects = variable_injects

    @property
    def volume_injects(self):
        """Gets the volume_injects of this ResponsePipelineStepRun.  # noqa: E501


        :return: The volume_injects of this ResponsePipelineStepRun.  # noqa: E501
        :rtype: dict[str, V1VolumeInject]
        """
        return self._volume_injects

    @volume_injects.setter
    def volume_injects(self, volume_injects):
        """Sets the volume_injects of this ResponsePipelineStepRun.


        :param volume_injects: The volume_injects of this ResponsePipelineStepRun.  # noqa: E501
        :type volume_injects: dict[str, V1VolumeInject]
        """

        self._volume_injects = volume_injects

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponsePipelineStepRun):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponsePipelineStepRun):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPipelineTrigger(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'edges': 'OrmPipelineTriggerEdges',
        'enabled': 'bool',
        'id': 'int',
        'kind': 'str',
        'name': 'str',
        'pipeline_id': 'int',
        'spec': 'dict[str, object]',
        'token': 'str'
    }

    attribute_map = {
        'description': 'description',
        'edges': 'edges',
        'enabled': 'enabled',
        'id': 'id',
        'kind': 'kind',
        'name': 'name',
        'pipeline_id': 'pipeline_id',
        'spec': 'spec',
        'token': 'token'
    }

    def __init__(self, description=None, edges=None, enabled=None, id=None, kind=None, name=None, pipeline_id=None, spec=None, token=None, local_vars_configuration=None):  # noqa: E501
        """OrmPipelineTrigger - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._description = None
        self._edges = None
        self._enabled = None
        self._id = None
        self._kind = None
        self._name = None
        self._pipeline_id = None
        self._spec = None
        self._token = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if edges is not None:
            self.edges = edges
        if enabled is not None:
            self.enabled = enabled
        if id is not None:
            self.id = id
        if kind is not None:
            self.kind = kind
        if name is not None:
            self.name = name
        if pipeline_id is not None:
            self.pipeline_id = pipeline_id
        if spec is not None:
            self.spec = spec
        if token is not None:
            self.token = token

    @property
    def description(self):
        """Gets the description of this OrmPipelineTrigger.  # noqa: E501


        :return: The description of this OrmPipelineTrigger.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OrmPipelineTrigger.


        :param description: The description of this OrmPipelineTrigger.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def edges(self):
        """Gets the edges of this OrmPipelineTrigger.  # noqa: E501


        :return: The edges of this OrmPipelineTrigger.  # noqa: E501
        :rtype: OrmPipelineTriggerEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmPipelineTrigger.


        :param edges: The edges of this OrmPipelineTrigger.  # noqa: E501
        :type edges: OrmPipelineTriggerEdges
        """

        self._edges = edges

    @property
    def enabled(self):
        """Gets the enabled of this OrmPipelineTrigger.  # noqa: E501


        :return: The enabled of this OrmPipelineTrigger.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this OrmPipelineTrigger.


        :param enabled: The enabled of this OrmPipelineTrigger.  # noqa: E501
        :type enabled: bool
        """

        self._enabled = enabled

    @property
    def id(self):
        """Gets the id of this OrmPipelineTrigger.  # noqa: E501


        :return: The id of this OrmPipelineTrigger.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmPipelineTrigger.


        :param id: The id of this OrmPipelineTrigger.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def kind(self):
        """Gets the kind of this OrmPipelineTrigger.  # noqa: E501


        :return: The kind of this OrmPipelineTrigger.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this OrmPipelineTrigger.


        :param kind: The kind of this OrmPipelineTrigger.  # noqa: E501
        :type kind: str
        """

        self._kind = kind

    @property
    def name(self):
        """Gets the name of this OrmPipelineTrigger.  # noqa: E501


        :return: The name of this OrmPipelineTrigger.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmPipelineTrigger.


        :param name: The name of this OrmPipelineTrigger.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def pipeline_id(self):
        """Gets the pipeline_id of this OrmPipelineTrigger.  # noqa: E501


        :return: The pipeline_id of this OrmPipelineTrigger.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_id

    @pipeline_id.setter
    def pipeline_id(self, pipeline_id):
        """Sets the pipeline_id of this OrmPipelineTrigger.


        :param pipeline_id: The pipeline_id of this OrmPipelineTrigger.  # noqa: E501
        :type pipeline_id: int
        """

        self._pipeline_id = pipeline_id

    @property
    def spec(self):
        """Gets the spec of this OrmPipelineTrigger.  # noqa: E501


        :return: The spec of this OrmPipelineTrigger.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this OrmPipelineTrigger.


        :param spec: The spec of this OrmPipelineTrigger.  # noqa: E501
        :type spec: dict[str, object]
        """

        self._spec = spec

    @property
    def token(self):
        """Gets the token of this OrmPipelineTrigger.  # noqa: E501


        :return: The token of this OrmPipelineTrigger.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this OrmPipelineTrigger.


        :param token: The token of this OrmPipelineTrigger.  # noqa: E501
        :type token: str
        """

        self._token = token

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPipelineTrigger):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPipelineTrigger):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmVolumeEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifacts': 'list[OrmArtifact]',
        'locator_origin': 'OrmArtifact',
        'models': 'list[OrmModel]',
        'organization': 'OrmOrganization',
        'pipeline': 'OrmPipeline',
        'run_exec': 'OrmRunExecution',
        'storage': 'OrmStorage'
    }

    attribute_map = {
        'artifacts': 'artifacts',
        'locator_origin': 'locator_origin',
        'models': 'models',
        'organization': 'organization',
        'pipeline': 'pipeline',
        'run_exec': 'run_exec',
        'storage': 'storage'
    }

    def __init__(self, artifacts=None, locator_origin=None, models=None, organization=None, pipeline=None, run_exec=None, storage=None, local_vars_configuration=None):  # noqa: E501
        """OrmVolumeEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifacts = None
        self._locator_origin = None
        self._models = None
        self._organization = None
        self._pipeline = None
        self._run_exec = None
        self._storage = None
        self.discriminator = None

        if artifacts is not None:
            self.artifacts = artifacts
        if locator_origin is not None:
            self.locator_origin = locator_origin
        if models is not None:
            self.models = models
        if organization is not None:
            self.organization = organization
        if pipeline is not None:
            self.pipeline = pipeline
        if run_exec is not None:
            self.run_exec = run_exec
        if storage is not None:
            self.storage = storage

    @property
    def artifacts(self):
        """Gets the artifacts of this OrmVolumeEdges.  # noqa: E501


        :return: The artifacts of this OrmVolumeEdges.  # noqa: E501
        :rtype: list[OrmArtifact]
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this OrmVolumeEdges.


        :param artifacts: The artifacts of this OrmVolumeEdges.  # noqa: E501
        :type artifacts: list[OrmArtifact]
        """

        self._artifacts = artifacts

    @property
    def locator_origin(self):
        """Gets the locator_origin of this OrmVolumeEdges.  # noqa: E501


        :return: The locator_origin of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmArtifact
        """
        return self._locator_origin

    @locator_origin.setter
    def locator_origin(self, locator_origin):
        """Sets the locator_origin of this OrmVolumeEdges.


        :param locator_origin: The locator_origin of this OrmVolumeEdges.  # noqa: E501
        :type locator_origin: OrmArtifact
        """

        self._locator_origin = locator_origin

    @property
    def models(self):
        """Gets the models of this OrmVolumeEdges.  # noqa: E501


        :return: The models of this OrmVolumeEdges.  # noqa: E501
        :rtype: list[OrmModel]
        """
        return self._models

    @models.setter
    def models(self, models):
        """Sets the models of this OrmVolumeEdges.


        :param models: The models of this OrmVolumeEdges.  # noqa: E501
        :type models: list[OrmModel]
        """

        self._models = models

    @property
    def organization(self):
        """Gets the organization of this OrmVolumeEdges.  # noqa: E501


        :return: The organization of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrmVolumeEdges.


        :param organization: The organization of this OrmVolumeEdges.  # noqa: E501
        :type organization: OrmOrganization
        """

        self._organization = organization

    @property
    def pipeline(self):
        """Gets the pipeline of this OrmVolumeEdges.  # noqa: E501


        :return: The pipeline of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmPipeline
        """
        return self._pipeline

    @pipeline.setter
    def pipeline(self, pipeline):
        """Sets the pipeline of this OrmVolumeEdges.


        :param pipeline: The pipeline of this OrmVolumeEdges.  # noqa: E501
        :type pipeline: OrmPipeline
        """

        self._pipeline = pipeline

    @property
    def run_exec(self):
        """Gets the run_exec of this OrmVolumeEdges.  # noqa: E501


        :return: The run_exec of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmRunExecution
        """
        return self._run_exec

    @run_exec.setter
    def run_exec(self, run_exec):
        """Sets the run_exec of this OrmVolumeEdges.


        :param run_exec: The run_exec of this OrmVolumeEdges.  # noqa: E501
        :type run_exec: OrmRunExecution
        """

        self._run_exec = run_exec

    @property
    def storage(self):
        """Gets the storage of this OrmVolumeEdges.  # noqa: E501


        :return: The storage of this OrmVolumeEdges.  # noqa: E501
        :rtype: OrmStorage
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        """Sets the storage of this OrmVolumeEdges.


        :param storage: The storage of this OrmVolumeEdges.  # noqa: E501
        :type storage: OrmStorage
        """

        self._storage = storage

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmVolumeEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmVolumeEdges):
            return True

        return self.to_dict() != other.to_dict()



import os

import click

from vessl.cli._base import VesslGroup, vessl_argument
from vessl.cli._util import (
    Endpoint,
    generic_prompter,
    print_data,
    print_info,
    print_success,
    print_table,
    print_volume_files,
    prompt_choices,
    truncate_datetime,
)
from vessl.cli.organization import organization_name_option
from vessl.dataset import (
    copy_dataset_volume_file,
    create_dataset,
    delete_dataset_volume_file,
    download_dataset_volume_file,
    list_dataset_volume_files,
    list_datasets,
    read_dataset,
    upload_dataset_volume_file,
)


def dataset_name_prompter(
    ctx: click.Context,
    param: click.Parameter,
    value: str,
) -> str:
    datasets = list_datasets()
    return prompt_choices("Dataset", [x.name for x in datasets])


def dataset_name_callback(
    ctx: click.Context,
    param: click.Parameter,
    value: str,
):
    if value:
        ctx.obj["dataset_name"] = value
    return value


def download_dest_path_prompter(
    ctx: click.Context,
    param: click.Parameter,
    value: str,
) -> str:
    return click.prompt(
        "Destination path",
        default=os.path.join(os.getcwd(), ctx.obj["dataset_name"])
        if ctx.obj.get("dataset_name")
        else ".",
    )


@click.command(name="dataset", cls=VesslGroup)
def cli():
    pass


@cli.vessl_command()
@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
@organization_name_option
def read(name: str):
    dataset = read_dataset(dataset_name=name)
    print_data(
        {
            "ID": dataset.id,
            "Name": dataset.name,
            "Organization": dataset.organization.name,
            "Versioning": dataset.is_version_enabled,
            "Volume ID": dataset.volume_id,
            "Source": dataset.source.provider,
        }
    )
    print_info(f"For more info: {Endpoint.dataset.format(dataset.organization.name, dataset.name)}")


@cli.vessl_command()
@organization_name_option
def list():
    datasets = list_datasets()
    print_table(
        datasets,
        ["Name", "Source", "Updated"],
        lambda x: [x.name, x.source.provider, truncate_datetime(x.updated_dt)],
    )


@cli.vessl_command()
@vessl_argument("name", type=click.STRING, required=True, prompter=generic_prompter("Dataset name"))
@click.option("-m", "--description", type=click.STRING)
@click.option(
    "--is-public",
    type=click.BOOL,
    is_flag=True,
    help="Required if dataset sourced from a public bucket.",
)
@click.option(
    "-e",
    "--external-path",
    type=click.STRING,
    help="AWS S3 or Google Cloud Storage bucket URL (starts with `s3://` or `gs://`).",
)
@click.option("--aws-role-arn", type=click.STRING, help="Required for S3 datasets.")
@click.option("--enable-versioning", is_flag=True)
@click.option(
    "--version-path",
    type=click.STRING,
    help="Required to version AWS S3 or Google Cloud Storage dataset.",
)
@organization_name_option
def create(
    name: str,
    description: str,
    is_public: bool,
    external_path: str,
    aws_role_arn: str,
    enable_versioning: bool,
    version_path: str,
):
    dataset = create_dataset(
        dataset_name=name,
        description=description,
        is_version_enabled=enable_versioning,
        is_public=is_public,
        external_path=external_path,
        aws_role_arn=aws_role_arn,
        version_path=version_path,
    )
    print_success(
        f"Created '{dataset.name}'.\n"
        f"For more info: {Endpoint.dataset.format(dataset.organization.name, dataset.name)}"
    )


@cli.vessl_command()
@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
@click.option("-p", "--path", type=click.Path(), default="", help="Defaults to root.")
@click.option("-r", "--recursive", is_flag=True)
@organization_name_option
def list_files(
    name: str,
    path: str,
    recursive: bool,
):
    files = list_dataset_volume_files(
        dataset_name=name,
        path=path,
        need_download_url=False,
        recursive=recursive,
    )
    print_volume_files(files)


@cli.vessl_command()
@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
@vessl_argument(
    "source",
    type=click.Path(exists=True),
    required=True,
    prompter=generic_prompter("Source path"),
)
@vessl_argument(
    "dest",
    type=click.Path(),
    required=True,
    prompter=generic_prompter("Destination path", default="/"),
)
@organization_name_option
def upload(name: str, source: str, dest: str):
    upload_dataset_volume_file(
        dataset_name=name,
        source_path=source,
        dest_path=dest,
    )


@cli.vessl_command()
@vessl_argument(
    "name",
    type=click.STRING,
    required=True,
    prompter=dataset_name_prompter,
    callback=dataset_name_callback,
)
@vessl_argument(
    "source",
    type=click.Path(),
    required=True,
    prompter=generic_prompter("Source path", default="/"),
)
@vessl_argument("dest", type=click.Path(), required=True, prompter=download_dest_path_prompter)
@organization_name_option
def download(name: str, source: str, dest: str):
    download_dataset_volume_file(
        dataset_name=name,
        source_path=source,
        dest_path=dest,
    )


@cli.vessl_command()
@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
@vessl_argument(
    "source", type=click.Path(), required=True, prompter=generic_prompter("Source path")
)
@vessl_argument(
    "dest",
    type=click.Path(),
    required=True,
    prompter=generic_prompter("Destination path"),
)
@organization_name_option
def copy(name: str, source: str, dest: str):
    copy_dataset_volume_file(
        dataset_name=name,
        source_path=source,
        dest_path=dest,
    )
    print_success(f"Copied {source} to {dest}.")


@cli.vessl_command()
@vessl_argument("name", type=click.STRING, required=True, prompter=dataset_name_prompter)
@vessl_argument("path", type=click.Path(), required=True, prompter=generic_prompter("File path"))
@organization_name_option
def delete_file(name: str, path: str):
    delete_dataset_volume_file(
        dataset_name=name,
        path=path,
    )
    print_success(f"Deleted {path}.")
